@@ -11,13 +11,14 @@ class QObject;
 class Library : public QObject{
     Q_OBJECT
 public:
-    Library(const QString &libraryDirectory, const QString &databasename, QObject *parent = 0);
+    Library(const QString &lD, const QString &databasename, QObject *parent = 0);
     ~Library();
+    void loadLibrary();
 
     void scanDirectory(const QString&);
 
-//    void loadBooksfromdb();
-//    void saveBooktodb(Book*);
+    void loadBooksfromdb();
+    void saveBooktodb(Book*);
     QList<Book*> getBooks();
 
 private:
@@ -25,11 +26,23 @@ private:
     void connectdb(const QString&);
     void saveBookProgress(Book*);
     void loadBookProgress(Book*);
-//    bool checkForChanges();
+    void saveBookmarks(Book*);
+    void loadBookmarks(Book*);
+    void saveAnnotations(Book*);
+    void loadAnnotations(Book*);
+    bool checkForChanges();
 
     QSqlDatabase database;
+    QString libraryDirectory;
 
     QList<Book*> books;
+
+public slots: 
+    void addToLibrary(Book*);
+    void addToLibrary(const QString&);
+
+signals:
+    void bookAdded(Book*);
 };
 
 #endif
