@@ -6,13 +6,11 @@
 #include <QToolBar>
 #include <QKeyEvent>
 #include "bookview.h"
-#include "selectordialog.h"
 
 class MainWindow : public QMainWindow{
     Q_OBJECT
 public:
-//    MainWindow(const QString &filename, QWidget *parent = 0);
-    MainWindow(QWidget *parent = 0);
+    MainWindow(osso_context_t *context = 0, QWidget *parent = 0);
     ~MainWindow();
 
     void openBook(const QString &filename);
@@ -20,6 +18,8 @@ public:
 
     void setFont(const QString&, int);
     void setColorMode(int);
+    void enableBacklightForcing(bool);
+    void setViewMode(BookViewMode);
 
 protected:
     bool eventFilter(QObject*, QEvent*);
@@ -29,16 +29,21 @@ protected:
 private:
     BookView *bookView;
     Book *currentBook;
-    SelectorDialog *dialog;
     QToolBar *toolbar;
     void grabZoomKeys(bool);
+    QTimer brightnessTimer;
+    osso_context_t *osso_context;
 
 public slots:
     void tocNavigation();
+    void viewBookmarks();
+    void viewAnnotations();
+    void forceBacklightOn();
 
 signals:
     void volumeDownPressed();
     void volumeUpPressed();
+    void closing();
 };
 
 #endif
