@@ -12,9 +12,7 @@ class StartUpList : public QWidget
     Q_OBJECT
 public:
     StartUpList(QWidget *parent = 0);
-    ~StartUpList();
 
-    void addBook(Book *book);
     void setScroller(QAbstractKineticScroller*);
 
 private:
@@ -22,12 +20,15 @@ private:
     QAbstractKineticScroller *scroller;
 
 public slots:
+    void addBook(Book *book);
     void openFilePushed();
     void openBookPushed(Book*);
+    void searchButtonPressed();
 
 signals:
     void openFile();
     void openBook(Book*);
+    void searchCatalogs();
 };
 
 #endif
