@@ -5,10 +5,13 @@
 #include <QResizeEvent>
 #include <QSettings>
 
+#include "libosso.h"
+
 #include "library.h"
 #include "startuplist.h"
 #include "mainwindow.h"
 #include "settingsdialog.h"
+#include "searchcatalogsview.h"
 
 class StartWindow : public QMainWindow
 {
@@ -23,10 +26,14 @@ protected:
 private:
     StartUpList *startUpList;
     MainWindow *readingUI;
+    SearchCatalogsView *searcCatalogsView;
     QListWidget *libraryList;
     QSettings *settings;
     void readSettings();
     Library *library;
+    osso_context_t *osso_context;
+
+    FeedBooks *feedBooksCatalog;
 
 
 public slots:
@@ -34,6 +41,13 @@ public slots:
     void openBook(Book*);
     void openSettingsDialog();
 
+    void searchCatalogs();
+    void searchCatalogsClosed();
+    
+    void bookViewClosed();
+
+    void showMessage(const QString);
+
 };
 
 #endif
